@@ -26,16 +26,7 @@ set_filename() {
 }
 
 
-if [ -d /proc/driver/nvidia -a ! -f /proc/driver/nvidia/version ]; then
-    proc_module_dirs=`ls /proc/driver/nvidia/ 2> /dev/null`
-    module_names="nvidia-frontend"
-    for instance in $proc_module_dirs; do
-        module_names="$module_names nvidia$instance"
-    done
-else
-    proc_module_dirs="."
-    module_names="nvidia"
-fi
+module_names="nvidia nvidia_drm nvidia_modeset nvidia_uvm nvidia_peermem"
 
 usage_bug_report_message() {
     echo "Please include the '$LOG_FILENAME' log file when reporting"
@@ -71,7 +62,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 34323106 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 34685233 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -229,7 +220,7 @@ report_command() {
     if [ -n "$1" ]; then
         echo "$1"
         echo ""
-        $1
+        $1 2>&1
         echo ""
     fi
 }
@@ -465,10 +456,8 @@ if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
         fi
     done
 
-    for subdir in $proc_module_dirs; do
-        for GPU in `ls /proc/driver/nvidia/$subdir/gpus/ 2> /dev/null`; do
-            append "/proc/driver/nvidia/$subdir/gpus/$GPU/power"
-        done
+    for GPU in `ls /proc/driver/nvidia/gpus/ 2> /dev/null`; do
+        append "/proc/driver/nvidia/gpus/$GPU/power"
     done
 fi
 
@@ -821,6 +810,18 @@ append /proc/sys/vm/compaction_proactiveness
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# module parameter values
+
+(
+    echo "____________________________________________"
+    echo ""
+    for name in $module_names; do
+        if [ -d "/sys/module/$name/parameters/" ]; then
+            grep -Hr . "/sys/module/$name/parameters/" 2> /dev/null
+        fi
+    done
+) | $GZIP_CMD >> $LOG_FILENAME
+
 # get any relevant kernel messages
 
 (
@@ -1013,22 +1014,15 @@ append "/proc/pci"
 append "/proc/iomem"
 append "/proc/mtrr"
 
-for subdir in $proc_module_dirs; do
-    append "/proc/driver/nvidia/$subdir/version"
-    append "/proc/driver/nvidia/$subdir/params"
-    append "/proc/driver/nvidia/$subdir/registry"
-done
+append "/proc/driver/nvidia/version"
+append "/proc/driver/nvidia/params"
+append "/proc/driver/nvidia/registry"
 
 if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
-    for subdir in $proc_module_dirs; do
-        for GPU in `ls /proc/driver/nvidia/$subdir/gpus/ 2> /dev/null`; do
-            append "/proc/driver/nvidia/$subdir/gpus/$GPU/information"
-    #VGX_SPECIFIC_CODE_START
-            append "/proc/driver/nvidia/$subdir/gpus/$GPU/unbindLock"
-    #VGX_SPECIFIC_CODE_END
-        done
-        append_glob "/proc/driver/nvidia/$subdir/warnings/*"
+    for GPU in `ls /proc/driver/nvidia/gpus/ 2> /dev/null`; do
+        append "/proc/driver/nvidia/gpus/$GPU/information"
     done
+    append_glob "/proc/driver/nvidia/warnings/*"
 fi
 
 append_glob "/proc/acpi/video/*/*/info"
@@ -1115,22 +1109,14 @@ done
                 echo ""
                 # don't fail here, continue
             else
-                for instance in $proc_module_dirs; do
-                    if [ $instance != '.' ]; then
-                        export __RM_MODULE_INSTANCE=$instance
-                        echo "NVIDIA Kernel module instance $instance"
-                    fi
+                echo "$nvidia_debugdump ${NVDD_ARGS}"
+                echo ""
+                $nvidia_debugdump ${NVDD_ARGS} -f $NVDD_TEMP_FILENAME 2> /dev/null
+                $base64 $NVDD_TEMP_FILENAME 2> /dev/null
+                echo ""
 
-                    echo "$nvidia_debugdump ${NVDD_ARGS}"
-                    echo ""
-                    $nvidia_debugdump ${NVDD_ARGS} -f $NVDD_TEMP_FILENAME 2> /dev/null
-                    $base64 $NVDD_TEMP_FILENAME 2> /dev/null
-                    echo ""
-
-                    # remove the temporary file when complete
-                    rm $NVDD_TEMP_FILENAME 2> /dev/null
-                    unset __RM_MODULE_INSTANCE
-                done
+                # remove the temporary file when complete
+                rm $NVDD_TEMP_FILENAME 2> /dev/null
             fi
         else
             echo "Skipping nvidia-debugdump output (base64 not found)"
@@ -1179,18 +1165,11 @@ if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
         nvidia_smi=`which nvidia-smi 2> /dev/null | head -n 1`
 
         if [ $? -eq 0 -a -x "$nvidia_smi" ]; then
-            for instance in $proc_module_dirs; do
-                if [ $instance != '.' ]; then
-                    export __RM_MODULE_INSTANCE=$instance
-                    echo "NVIDIA Kernel module instance $instance"
-                fi
-                report_command "$nvidia_smi --query"
-                report_command "$nvidia_smi --query --unit"
-                report_command "$nvidia_smi nvlink --errorcounters"
-                report_command "$nvidia_smi nvlink --remotelinkinfo"
-                report_command "$nvidia_smi nvlink --status"
-                unset __RM_MODULE_INSTANCE
-            done
+            report_command "$nvidia_smi --query"
+            report_command "$nvidia_smi --query --unit"
+            report_command "$nvidia_smi nvlink --errorcounters"
+            report_command "$nvidia_smi nvlink --remotelinkinfo"
+            report_command "$nvidia_smi nvlink --status"
         else
             echo "Skipping nvidia-smi output (nvidia-smi not found)"
             echo ""
@@ -1317,6 +1296,115 @@ fi
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+dump_mlx() {
+    if [ -z "${TMPDIR}" ]; then
+        tmp_dir="/tmp"
+    else
+        tmp_dir="${TMPDIR}"
+    fi
+    MLX_CSV="$tmp_dir/mlx$$.csv"
+    MLX_INFO="$tmp_dir/mlx$$.info"
+    # mlxlink --amber_collect file will dump information to the specified csv file, and
+    # print information to stdout (in color).
+    # Capture both and remove the color escape characters.
+    for port in $(seq 1 5); do
+        echo "$1 -d $2 -p $port --amber_collect $MLX_CSV > $MLX_INFO 2>&1"
+        "$1" -d "$2" -p $port --amber_collect "$MLX_CSV" > "$MLX_INFO" 2>&1
+        if [ $? -eq 0 ]; then
+            cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
+            cat "$MLX_CSV" 2> /dev/null
+            echo "____________________________________________"
+            echo ""
+            rm -f "$MLX_INFO" 2> /dev/null
+            rm -f "$MLX_CSV" 2> /dev/null
+            break
+        else
+            echo "failed with error $? retrying..."
+            cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
+            rm -f "$MLX_INFO" 2> /dev/null
+            rm -f "$MLX_CSV" 2> /dev/null
+            echo "____________________________________________"
+        fi
+    done
+}
+
+(
+    mst=`which mst 2> /dev/null | head -n 1`
+
+    if [ $? -eq 0 -a -x "$mst" ]; then
+
+        mlxlink=`which mlxlink 2> /dev/null | head -n 1`
+
+        if [ $? -eq 0 -a -x "$mlxlink" ]; then
+            # loads PCI driver & creates PCI devices file descriptors under /dev/mst/.
+            echo "____________________________________________"
+            echo ""
+            report_command "$mst start"
+            echo "____________________________________________"
+            echo ""
+
+            # scans and adds gpu devices
+            report_command "$mst gpu add"
+            echo "____________________________________________"
+            echo ""
+
+            # scans and add ib devices
+            report_command "$mst ib add mlx5_0"
+            echo "____________________________________________"
+            echo ""
+
+            resourcedump=`which resourcedump 2> /dev/null | head -n 1`
+            mstdump=`which mstdump 2> /dev/null | head -n 1`
+
+            # dumps all the scanned devices
+            report_command "$mst status -v"
+            echo "____________________________________________"
+            echo ""
+
+            # Iterate and get dumps for each of the supported devices
+            "$mst" status -v |
+            {
+                while read tmp_line
+                do
+                echo $tmp_line | grep "netir" > /dev/null  2>&1
+                if [ $? -eq 0 ]; then
+                    echo "Starting GPU MST dump..."$tmp_line
+                    devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $1}';`
+                    dump_mlx "$mlxlink" "$devName"
+                    if [ ! -z "$resourcedump" ]; then
+                        report_command "$resourcedump dump -d $devName -s 0x5025"
+                        echo "____________________________________________"
+                        echo ""
+                    fi
+                fi
+                echo $tmp_line | grep "Quantum" | grep "mlx5_0" > /dev/null 2>&1
+                if [ $? -eq 0 ]; then
+                    echo "Starting Quantum dump..."$tmp_line
+                    devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $1}';`
+                    dump_mlx "$mlxlink" "$devName"
+                    if [ ! -z "$resourcedump" ]; then
+                        report_command "$resourcedump dump -d $devName -s 0x5025"
+                        echo "____________________________________________"
+                        echo ""
+                    fi
+                fi
+                echo $tmp_line | grep "ConnectX" | grep "pciconf0.[2,3]" > /dev/null 2>&1
+                if [ $? -eq 0 ]; then
+                    echo "Starting ConnectX dump..."$tmp_line
+                    devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $2}';`
+                    dump_mlx "$mlxlink" "$devName"
+                    if [ ! -z "$mstdump" ]; then
+                        report_command "$mstdump $devName"
+                        echo "____________________________________________"
+                        echo ""
+                    fi
+                fi
+                done
+            }
+        fi
+    fi
+) | $GZIP_CMD >> $LOG_FILENAME
+
 (
     echo "____________________________________________"
 
